@@ -25,6 +25,7 @@
 import sys
 import os.path
 import googletrans
+from progress.bar import Bar
 from colored import fore, style
 from googletrans import Translator
 from subtrs.__metadata__ import __prog__, __version__
@@ -73,16 +74,20 @@ class Subtitles:
             cap_file = self.file.split('/')[-1]
             new_captions = f'{cap_file[:-4]}_{lang}{self.ext}'
             with open(new_captions, 'w') as new_subs:
+                bar = Bar('Processing', max=len(self.f))
                 for line in self.f:
                     if line and not line[0].isdigit():
-                        if len(line) > 1 and '--silent' not in self.flags:
+                        if len(line) > 1 and '--progress' not in self.flags:
                             print(f'[{self.detect_lang(line)}]{self.IN_COLOR}'
                                   f' <<{self.RESET_COLOR} {line}')
                         line = self.translate(line, lang)
-                        if len(line) > 1 and '--silent' not in self.flags:
+                        if len(line) > 1 and '--progress' not in self.flags:
                             print(f'[{lang}]{self.OUT_COLOR} >> '
                                   f'{self.TRS_COLOR}{line}{self.RESET_COLOR}')
                     new_subs.write(line)
+                    if '--progress' in self.flags:
+                        bar.next()
+                bar.finish()
             self.created_file(new_captions)
 
     def translate(self, line, lang):
@@ -121,9 +126,9 @@ def usage(status):
             '       Destination languages [en,de,ru] etc.\n',
             'Optional arguments:',
             '       --color      View translate text language with colour.',
-            '       --silent     Silent method, without viewing.',
+            '       --progress   Show progress bar.',
             '  -l,  --languages  Show all supported languages.',
-            '  -v,  --version    Show the version and exit.',
+            '  -v,  --version    Print the version and exit.',
             '  -h,  --help       Show this message and exit.',
             ]
     for opt in args:
@@ -137,9 +142,9 @@ def args_flags(args):
     if '--color' in args:
         args.remove('--color')
         flags.append('--color')
-    if '--silent' in args:
-        args.remove('--silent')
-        flags.append('--silent')
+    if '--progress' in args:
+        args.remove('--progress')
+        flags.append('--progress')
     return flags
 
 
